@@ -52,12 +52,10 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
     if (this == o) {
       return true;
     }
-    if (!(o instanceof ColumnStatisticsImpl)) {
+    if (!(o instanceof ColumnStatisticsImpl that)) {
       return false;
     }
 
-    ColumnStatisticsImpl that = (ColumnStatisticsImpl) o;
-
     if (count != that.count) {
       return false;
     }
@@ -102,8 +100,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof BooleanStatisticsImpl) {
-        BooleanStatisticsImpl bkt = (BooleanStatisticsImpl) other;
+      if (other instanceof BooleanStatisticsImpl bkt) {
         trueCount += bkt.trueCount;
       } else {
         if (isStatsExists() && trueCount != 0) {
@@ -143,15 +140,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof BooleanStatisticsImpl)) {
+      if (!(o instanceof BooleanStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      BooleanStatisticsImpl that = (BooleanStatisticsImpl) o;
-
       return trueCount == that.trueCount;
     }
 
@@ -213,8 +208,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof CollectionColumnStatisticsImpl) {
-        CollectionColumnStatisticsImpl otherColl = (CollectionColumnStatisticsImpl) other;
+      if (other instanceof CollectionColumnStatisticsImpl otherColl) {
 
         if(count == 0) {
           minimum = otherColl.minimum;
@@ -272,15 +266,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof CollectionColumnStatisticsImpl)) {
+      if (!(o instanceof CollectionColumnStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      CollectionColumnStatisticsImpl that = (CollectionColumnStatisticsImpl) o;
-
       if (minimum != that.minimum) {
         return false;
       }
@@ -383,8 +375,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof IntegerStatisticsImpl) {
-        IntegerStatisticsImpl otherInt = (IntegerStatisticsImpl) other;
+      if (other instanceof IntegerStatisticsImpl otherInt) {
         if (!hasMinimum) {
           hasMinimum = otherInt.hasMinimum;
           minimum = otherInt.minimum;
@@ -471,15 +462,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof IntegerStatisticsImpl)) {
+      if (!(o instanceof IntegerStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      IntegerStatisticsImpl that = (IntegerStatisticsImpl) o;
-
       if (minimum != that.minimum) {
         return false;
       }
@@ -557,8 +546,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof DoubleStatisticsImpl) {
-        DoubleStatisticsImpl dbl = (DoubleStatisticsImpl) other;
+      if (other instanceof DoubleStatisticsImpl dbl) {
         if (!hasMinimum) {
           hasMinimum = dbl.hasMinimum;
           minimum = dbl.minimum;
@@ -628,15 +616,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof DoubleStatisticsImpl)) {
+      if (!(o instanceof DoubleStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      DoubleStatisticsImpl that = (DoubleStatisticsImpl) o;
-
       if (hasMinimum != that.hasMinimum) {
         return false;
       }
@@ -753,8 +739,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof StringStatisticsImpl) {
-        StringStatisticsImpl str = (StringStatisticsImpl) other;
+      if (other instanceof StringStatisticsImpl str) {
         if (count == 0) {
           if (str.count != 0) {
             minimum = new Text(str.minimum);
@@ -884,15 +869,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof StringStatisticsImpl)) {
+      if (!(o instanceof StringStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      StringStatisticsImpl that = (StringStatisticsImpl) o;
-
       if (sum != that.sum) {
         return false;
       }
@@ -1050,15 +1033,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof BinaryStatisticsImpl)) {
+      if (!(o instanceof BinaryStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      BinaryStatisticsImpl that = (BinaryStatisticsImpl) o;
-
       return sum == that.sum;
     }
 
@@ -1129,8 +1110,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof DecimalStatisticsImpl) {
-        DecimalStatisticsImpl dec = (DecimalStatisticsImpl) other;
+      if (other instanceof DecimalStatisticsImpl dec) {
         if (minimum == null) {
           minimum = (dec.minimum != null ? new HiveDecimalWritable(dec.minimum) : null);
           maximum = (dec.maximum != null ? new HiveDecimalWritable(dec.maximum) : null);
@@ -1209,15 +1189,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof DecimalStatisticsImpl)) {
+      if (!(o instanceof DecimalStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      DecimalStatisticsImpl that = (DecimalStatisticsImpl) o;
-
       if (minimum != null ? !minimum.equals(that.minimum) : that.minimum != null) {
         return false;
       }
@@ -1323,8 +1301,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof Decimal64StatisticsImpl) {
-        Decimal64StatisticsImpl dec = (Decimal64StatisticsImpl) other;
+      if (other instanceof Decimal64StatisticsImpl dec) {
         if (getNumberOfValues() == 0) {
           minimum = dec.minimum;
           maximum = dec.maximum;
@@ -1420,15 +1397,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof Decimal64StatisticsImpl)) {
+      if (!(o instanceof Decimal64StatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      Decimal64StatisticsImpl that = (Decimal64StatisticsImpl) o;
-
       if (minimum != that.minimum ||
           maximum != that.maximum ||
           hasSum != that.hasSum) {
@@ -1508,8 +1483,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof DateStatisticsImpl) {
-        DateStatisticsImpl dateStats = (DateStatisticsImpl) other;
+      if (other instanceof DateStatisticsImpl dateStats) {
         minimum = Math.min(minimum, dateStats.minimum);
         maximum = Math.max(maximum, dateStats.maximum);
       } else {
@@ -1588,15 +1562,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof DateStatisticsImpl)) {
+      if (!(o instanceof DateStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      DateStatisticsImpl that = (DateStatisticsImpl) o;
-
       if (minimum != that.minimum) {
         return false;
       }
@@ -1702,8 +1674,7 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
 
     @Override
     public void merge(ColumnStatisticsImpl other) {
-      if (other instanceof TimestampStatisticsImpl) {
-        TimestampStatisticsImpl timestampStats = (TimestampStatisticsImpl) other;
+      if (other instanceof TimestampStatisticsImpl timestampStats) {
         if (count == 0) {
           if (timestampStats.count != 0) {
             minimum = timestampStats.minimum;
@@ -1817,15 +1788,13 @@ public class ColumnStatisticsImpl implements ColumnStatistics {
       if (this == o) {
         return true;
       }
-      if (!(o instanceof TimestampStatisticsImpl)) {
+      if (!(o instanceof TimestampStatisticsImpl that)) {
         return false;
       }
       if (!super.equals(o)) {
         return false;
       }
 
-      TimestampStatisticsImpl that = (TimestampStatisticsImpl) o;
-
       return minimum == that.minimum && maximum == that.maximum &&
           minNanos == that.minNanos && maxNanos == that.maxNanos;
     }
