@@ -17,46 +17,37 @@
  */
 package org.apache.orc;
 
-import static junit.framework.Assert.assertEquals;
-
-import java.io.File;
-import java.sql.Timestamp;
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.List;
-import java.util.Random;
-
+import com.google.common.collect.Lists;
+import com.google.common.primitives.Longs;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.ql.exec.vector.LongColumnVector;
 import org.apache.hadoop.hive.ql.exec.vector.TimestampColumnVector;
 import org.apache.hadoop.hive.ql.exec.vector.VectorizedRowBatch;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TestName;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-import org.junit.runners.Parameterized.Parameters;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.MethodSource;
 
-import com.google.common.collect.Lists;
-import com.google.common.primitives.Longs;
+import java.io.File;
+import java.sql.Timestamp;
+import java.util.List;
+import java.util.Random;
+import java.util.stream.Stream;
+
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-@RunWith(value = Parameterized.class)
 public class TestNewIntegerEncoding {
 
-  private OrcFile.EncodingStrategy encodingStrategy;
-
-  public TestNewIntegerEncoding( OrcFile.EncodingStrategy es) {
-    this.encodingStrategy = es;
-  }
-
-  @Parameters
-  public static Collection<Object[]> data() {
-    Object[][] data = new Object[][] { {  OrcFile.EncodingStrategy.COMPRESSION },
-        {  OrcFile.EncodingStrategy.SPEED } };
-    return Arrays.asList(data);
+  private static Stream<Arguments> data() {
+    return Stream.of(
+        Arguments.of(OrcFile.EncodingStrategy.COMPRESSION),
+        Arguments.of(OrcFile.EncodingStrategy.SPEED));
   }
 
   public static TypeDescription getRowSchema() {
@@ -85,20 +76,18 @@ public class TestNewIntegerEncoding {
   FileSystem fs;
   Path testFilePath;
 
-  @Rule
-  public TestName testCaseName = new TestName();
-
-  @Before
-  public void openFileSystem() throws Exception {
+  @BeforeEach
+  public void openFileSystem(TestInfo testInfo) throws Exception {
     conf = new Configuration();
     fs = FileSystem.getLocal(conf);
     testFilePath = new Path(workDir, "TestOrcFile."
-        + testCaseName.getMethodName() + ".orc");
+        + testInfo.getTestMethod().get().getName() + ".orc");
     fs.delete(testFilePath, false);
   }
 
-  @Test
-  public void testBasicRow() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicRow(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema= getRowSchema();
     Writer writer = OrcFile.createWriter(testFilePath,
                                          OrcFile.writerOptions(conf)
@@ -126,8 +115,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicOld() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicOld(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
     long[] inp = new long[] { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6,
         7, 8, 9, 10, 1, 1, 1, 1, 1, 1, 10, 9, 7, 6, 5, 4, 3, 2, 1, 1, 1, 1, 1,
@@ -162,8 +152,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicNew() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicNew(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 3, 4, 5, 6,
@@ -200,8 +191,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicDelta1() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicDelta1(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { -500, -400, -350, -325, -310 };
@@ -234,8 +226,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicDelta2() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicDelta2(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { -500, -600, -650, -675, -710 };
@@ -268,8 +261,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicDelta3() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicDelta3(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 500, 400, 350, 325, 310 };
@@ -302,8 +296,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testBasicDelta4() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testBasicDelta4(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 500, 600, 650, 675, 710 };
@@ -340,9 +335,9 @@ public class TestNewIntegerEncoding {
   public void testDeltaOverflow() throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
-    long[] inp = new long[]{4513343538618202719l, 4513343538618202711l,
-        2911390882471569739l,
-        -9181829309989854913l};
+    long[] inp = new long[]{4513343538618202719L, 4513343538618202711L,
+        2911390882471569739L,
+        -9181829309989854913L};
     List<Long> input = Lists.newArrayList(Longs.asList(inp));
 
     Writer writer = OrcFile.createWriter(
@@ -373,8 +368,8 @@ public class TestNewIntegerEncoding {
   public void testDeltaOverflow2() throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
-    long[] inp = new long[]{Long.MAX_VALUE, 4513343538618202711l,
-        2911390882471569739l,
+    long[] inp = new long[]{Long.MAX_VALUE, 4513343538618202711L,
+        2911390882471569739L,
         Long.MIN_VALUE};
     List<Long> input = Lists.newArrayList(Longs.asList(inp));
 
@@ -406,7 +401,7 @@ public class TestNewIntegerEncoding {
   public void testDeltaOverflow3() throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
-    long[] inp = new long[]{-4513343538618202711l, -2911390882471569739l, -2,
+    long[] inp = new long[]{-4513343538618202711L, -2911390882471569739L, -2,
         Long.MAX_VALUE};
     List<Long> input = Lists.newArrayList(Longs.asList(inp));
 
@@ -434,8 +429,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testIntegerMin() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testIntegerMin(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -467,8 +463,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testIntegerMax() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testIntegerMax(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -501,8 +498,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testLongMin() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testLongMin(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -535,8 +533,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testLongMax() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testLongMax(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -569,8 +568,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testRandomInt() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testRandomInt(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -606,8 +606,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testRandomLong() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testRandomLong(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -643,8 +644,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseNegativeMin() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseNegativeMin(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 20, 2, 3, 2, 1, 3, 17, 71, 35, 2, 1, 139, 2, 2,
@@ -688,8 +690,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseNegativeMin2() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseNegativeMin2(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 20, 2, 3, 2, 1, 3, 17, 71, 35, 2, 1, 139, 2, 2,
@@ -733,8 +736,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseNegativeMin3() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseNegativeMin3(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 20, 2, 3, 2, 1, 3, 17, 71, 35, 2, 1, 139, 2, 2,
@@ -778,8 +782,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseNegativeMin4() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseNegativeMin4(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     long[] inp = new long[] { 13, 13, 11, 8, 13, 10, 10, 11, 11, 14, 11, 7, 13,
@@ -814,8 +819,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseAt0() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseAt0(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -852,8 +858,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseAt1() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseAt1(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -889,8 +896,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseAt255() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseAt255(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -926,8 +934,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseAt256() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseAt256(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -963,8 +972,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBase510() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBase510(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1000,8 +1010,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBase511() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBase511(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1037,8 +1048,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseMax1() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseMax1(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1074,8 +1086,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseMax2() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseMax2(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1113,8 +1126,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseMax3() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseMax3(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1164,8 +1178,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseMax4() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseMax4(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
@@ -1219,8 +1234,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testPatchedBaseTimestamp() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testPatchedBaseTimestamp(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createStruct()
         .addField("ts", TypeDescription.createTimestamp());
 
@@ -1288,8 +1304,9 @@ public class TestNewIntegerEncoding {
     }
   }
 
-  @Test
-  public void testDirectLargeNegatives() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testDirectLargeNegatives(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     Writer writer = OrcFile.createWriter(testFilePath,
@@ -1312,7 +1329,7 @@ public class TestNewIntegerEncoding {
         OrcFile.readerOptions(conf).filesystem(fs));
     RecordReader rows = reader.rows();
     batch = reader.getSchema().createRowBatch();
-    assertEquals(true, rows.nextBatch(batch));
+    assertTrue(rows.nextBatch(batch));
     assertEquals(5, batch.size);
     assertEquals(-7486502418706614742L,
         ((LongColumnVector) batch.cols[0]).vector[0]);
@@ -1324,11 +1341,12 @@ public class TestNewIntegerEncoding {
         ((LongColumnVector) batch.cols[0]).vector[3]);
     assertEquals(-5535739865598783616L,
         ((LongColumnVector) batch.cols[0]).vector[4]);
-    assertEquals(false, rows.nextBatch(batch));
+    assertFalse(rows.nextBatch(batch));
   }
 
-  @Test
-  public void testSeek() throws Exception {
+  @ParameterizedTest
+  @MethodSource("data")
+  public void testSeek(OrcFile.EncodingStrategy encodingStrategy) throws Exception {
     TypeDescription schema = TypeDescription.createLong();
 
     List<Long> input = Lists.newArrayList();
